<template>
  <div class="app-container">
    <!-- 对话框(添加 / 修改) -->
    <el-dialog :title="dialogTitle" :visible.sync="dialogVisible" width="45%" v-dialogDrag
               append-to-body>
      <el-form ref="formRef" :model="formData" :rules="formRules" v-loading="formLoading"
               label-width="100px">
        <el-form-item label="模型id" prop="modelId">
          <el-input v-model="formData.modelId" placeholder="请输入模型id"/>
        </el-form-item>
        <el-form-item label="问题编号" prop="questionCode">
          <el-input v-model="formData.questionCode" placeholder="请输入问题编号"/>
        </el-form-item>
        <el-form-item label="问题名称" prop="questionName">
          <el-input v-model="formData.questionName" placeholder="请输入问题名称"/>
        </el-form-item>
        <el-form-item label="问题内容">
          <Editor v-model="formData.questionContent" :min-height="192"/>
        </el-form-item>
        <el-form-item label="输入个数" prop="dataLength">
          <el-input v-model="formData.dataLength" placeholder="请输入输入个数"/>
        </el-form-item>
        <el-form-item label="是否启用（0禁用 1启用）" prop="isEnable">
          <el-input v-model="formData.isEnable" placeholder="请输入是否启用（0禁用 1启用）"/>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="formData.remark" placeholder="请输入备注"/>
        </el-form-item>
        <el-form-item label="创建时间" prop="createDate">
          <el-date-picker clearable v-model="formData.createDate" type="date"
                          value-format="timestamp" placeholder="选择创建时间"/>
        </el-form-item>
        <el-form-item label="更新者" prop="updator">
          <el-input v-model="formData.updator" placeholder="请输入更新者"/>
        </el-form-item>
        <el-form-item label="更新时间" prop="updateDate">
          <el-date-picker clearable v-model="formData.updateDate" type="date"
                          value-format="timestamp" placeholder="选择更新时间"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm" :disabled="formLoading">确 定</el-button>
        <el-button @click="dialogVisible = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import * as QuestionTemplateApi from '@/api/ai/questiontemplate';
import Editor from '@/components/Editor';

export default {
  name: "QuestionTemplateForm",
  components: {
    Editor,
  },
  data() {
    return {
      // 弹出层标题
      dialogTitle: "",
      // 是否显示弹出层
      dialogVisible: false,
      // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
      formLoading: false,
      // 表单参数
      formData: {
        id: undefined,
        modelId: undefined,
        questionCode: undefined,
        questionName: undefined,
        questionContent: undefined,
        dataLength: undefined,
        isEnable: undefined,
        remark: undefined,
        createDate: undefined,
        updator: undefined,
        updateDate: undefined,
      },
      // 表单校验
      formRules: {
        modelId: [{required: true, message: '模型id不能为空', trigger: 'blur'}],
        questionCode: [{required: true, message: '问题编号不能为空', trigger: 'blur'}],
      },
    };
  },
  methods: {
    /** 打开弹窗 */
    async open(id) {
      this.dialogVisible = true;
      this.reset();
      // 修改时，设置数据
      if (id) {
        this.formLoading = true;
        try {
          const res = await QuestionTemplateApi.getQuestionTemplate(id);
          this.formData = res.data;
          this.title = "修改大模型问题模板";
        } finally {
          this.formLoading = false;
        }
      }
      this.title = "新增大模型问题模板";
    },
    /** 提交按钮 */
    async submitForm() {
      // 校验主表
      await this.$refs["formRef"].validate();
      this.formLoading = true;
      try {
        const data = this.formData;
        // 修改的提交
        if (data.id) {
          await QuestionTemplateApi.updateQuestionTemplate(data);
          this.$modal.msgSuccess("修改成功");
          this.dialogVisible = false;
          this.$emit('success');
          return;
        }
        // 添加的提交
        await QuestionTemplateApi.createQuestionTemplate(data);
        this.$modal.msgSuccess("新增成功");
        this.dialogVisible = false;
        this.$emit('success');
      } finally {
        this.formLoading = false;
      }
    },
    /** 表单重置 */
    reset() {
      this.formData = {
        id: undefined,
        modelId: undefined,
        questionCode: undefined,
        questionName: undefined,
        questionContent: undefined,
        dataLength: undefined,
        isEnable: undefined,
        remark: undefined,
        createDate: undefined,
        updator: undefined,
        updateDate: undefined,
      };
      this.resetForm("formRef");
    }
  }
};
</script>
